==========
NOTEBOOKS
==========

* A `2D gauss <http://nbviewer.ipython.org/github/jakeret/abcpmc/blob/master/notebooks/2d_gauss.ipynb>`_ case study 

* A `toy model <http://nbviewer.ipython.org/github/jakeret/abcpmc/blob/master/notebooks/toy_model.ipynb>`_ including a comparison to theoretical predictions
	
* A `multi distance sampling <http://nbviewer.ipython.org/github/jakeret/abcpmc/blob/master/notebooks/dual_abc_pmc.ipynb>`_ example
	
	
